@@ -53,7 +53,7 @@
 #include <ctype.h>
 #include <tic.h>
 
-MODULE_ID("$Id: lib_tparm.c,v 1.154 2024/07/27 19:22:23 tom Exp $")
+MODULE_ID("$Id: lib_tparm.c,v 1.155 2024/12/07 18:26:59 tom Exp $")
 
 /*
  *	char *
@@ -343,7 +343,7 @@ static NCURSES_INLINE int
 #define spop(tps) \
     ((TPS(stack_ptr)-- > 0) \
      ? ((!TPS(stack)[TPS(stack_ptr)].num_type \
-        && TPS(stack)[TPS(stack_ptr)].data.str != 0) \
+        && TPS(stack)[TPS(stack_ptr)].data.str != NULL) \
          ? TPS(stack)[TPS(stack_ptr)].data.str \
          : dummy) \
      : (tparm_error(tps, "spop: stack underflow"), \
@@ -361,7 +361,7 @@ static NCURSES_INLINE const char *
 parse_format(const char *s, char *format, int *len)
 {
     *len = 0;
-    if (format != 0) {
+    if (format != NULL) {
 	bool done = FALSE;
 	bool allowminus = FALSE;
 	bool dot = FALSE;
@@ -475,13 +475,13 @@ _nc_tparm_analyze(TERMINAL *term, const char *string, char **p_is_s, int *popcou
     int level = -1;
     const char *cp = string;
 
-    if (cp == 0)
+    if (cp == NULL)
 	return 0;
 
     if ((len2 = strlen(cp)) + 2 > TPS(fmt_size)) {
 	TPS(fmt_size) += len2 + 2;
 	TPS(fmt_buff) = typeRealloc(char, TPS(fmt_size), TPS(fmt_buff));
-	if (TPS(fmt_buff) == 0)
+	if (TPS(fmt_buff) == NULL)
 	    return 0;
     }
 
@@ -616,14 +616,14 @@ tparm_setup(TERMINAL *term, const char *string, TPARM_DATA *result)
 	void *ft;
 
 	result->format = string;
-	if ((ft = tfind(result, &MyCache, cmp_format)) != 0) {
+	if ((ft = tfind(result, &MyCache, cmp_format)) != NULL) {
 	    size_t len2;
 	    fs = *(TPARM_DATA **) ft;
 	    *result = *fs;
 	    if ((len2 = strlen(string)) + 2 > TPS(fmt_size)) {
 		TPS(fmt_size) += len2 + 2;
 		TPS(fmt_buff) = typeRealloc(char, TPS(fmt_size), TPS(fmt_buff));
-		if (TPS(fmt_buff) == 0)
+		if (TPS(fmt_buff) == NULL)
 		    return ERR;
 	    }
 	} else
@@ -637,7 +637,7 @@ tparm_setup(TERMINAL *term, const char *string, TPARM_DATA *result)
 	    result->num_parsed = _nc_tparm_analyze(term, string,
 						   result->p_is_s,
 						   &(result->num_popped));
-	    if (TPS(fmt_buff) == 0) {
+	    if (TPS(fmt_buff) == NULL) {
 		TR(TRACE_CALLS, ("%s: error in analysis", TPS(tname)));
 		rc = ERR;
 	    } else {
@@ -654,10 +654,10 @@ tparm_setup(TERMINAL *term, const char *string, TPARM_DATA *result)
 			result->tparm_type |= (1 << n);
 		}
 #if HAVE_TSEARCH
-		if ((fs = typeCalloc(TPARM_DATA, 1)) != 0) {
+		if ((fs = typeCalloc(TPARM_DATA, 1)) != NULL) {
 		    *fs = *result;
-		    if ((fs->format = strdup(string)) != 0) {
-			if (tsearch(fs, &MyCache, cmp_format) != 0) {
+		    if ((fs->format = strdup(string)) != NULL) {
+			if (tsearch(fs, &MyCache, cmp_format) != NULL) {
 			    ++MyCount;
 			} else {
 			    free(fs);
@@ -690,9 +690,9 @@ tparm_copy_valist(TPARM_DATA *data, int use_TPARM_ARG, va_list ap)
     int i;
 
     for (i = 0; i < data->num_actual; i++) {
-	if (data->p_is_s[i] != 0) {
+	if (data->p_is_s[i] != NULL) {
 	    char *value = va_arg(ap, char *);
-	    if (value == 0)
+	    if (value == NULL)
 		value = dummy;
 	    data->p_is_s[i] = value;
 	    data->param[i] = 0;
@@ -740,7 +740,7 @@ tparm_trace_call(TPARM_STATE *tps, const char *string, TPARM_DATA *data)
     if (USE_TRACEF(TRACE_CALLS)) {
 	int i;
 	for (i = 0; i < data->num_actual; i++) {
-	    if (data->p_is_s[i] != 0) {
+	    if (data->p_is_s[i] != NULL) {
 		save_text(tps, ", %s", _nc_visbuf(data->p_is_s[i]), 0);
 	    } else if ((long) data->param[i] > MAX_OF_TYPE(NCURSES_INT2) ||
 		       (long) data->param[i] < 0) {
@@ -1003,12 +1003,12 @@ tparam_internal(TPARM_STATE *tps, const char *string, TPARM_DATA *data)
 		 */
 		if (!incremented_two) {
 		    incremented_two = TRUE;
-		    if (data->p_is_s[0] == 0) {
+		    if (data->p_is_s[0] == NULL) {
 			data->param[0]++;
 			if (termcap_hack)
 			    TPS(stack)[0].data.num = (int) data->param[0];
 		    }
-		    if (data->p_is_s[1] == 0) {
+		    if (data->p_is_s[1] == NULL) {
 			data->param[1]++;
 			if (termcap_hack)
 			    TPS(stack)[1].data.num = (int) data->param[1];
