@@ -42,7 +42,7 @@
 
 #include <tic.h>
 
-MODULE_ID("$Id: read_entry.c,v 1.173 2024/07/27 23:07:02 tom Exp $")
+MODULE_ID("$Id: read_entry.c,v 1.174 2024/12/07 21:02:00 tom Exp $")
 
 #define MyNumber(n) (short) LOW_MSB(n)
 
@@ -237,11 +237,11 @@ _nc_init_termtype(TERMTYPE2 *const tp)
     tp->ext_Numbers = 0;
     tp->ext_Strings = 0;
 #endif
-    if (tp->Booleans == 0)
+    if (tp->Booleans == NULL)
 	TYPE_MALLOC(NCURSES_SBOOL, BOOLCOUNT, tp->Booleans);
-    if (tp->Numbers == 0)
+    if (tp->Numbers == NULL)
 	TYPE_MALLOC(NCURSES_INT2, NUMCOUNT, tp->Numbers);
-    if (tp->Strings == 0)
+    if (tp->Strings == NULL)
 	TYPE_MALLOC(char *, STRCOUNT, tp->Strings);
 
     for_each_boolean(i, tp)
@@ -346,7 +346,7 @@ _nc_read_termtype(TERMTYPE2 *ptr, char *buffer, int limit)
     want = (unsigned) (str_size + name_size + 1);
     /* try to allocate space for the string table */
     if (str_count * SIZEOF_SHORT >= max_entry_size
-	|| (string_table = typeMalloc(char, want)) == 0) {
+	|| (string_table = typeMalloc(char, want)) == NULL) {
 	returnDB(TGETENT_NO);
     }
 
@@ -483,7 +483,7 @@ _nc_read_termtype(TERMTYPE2 *ptr, char *buffer, int limit)
 
 	if (ext_str_limit) {
 	    ptr->ext_str_table = typeMalloc(char, (size_t) ext_str_limit);
-	    if (ptr->ext_str_table == 0) {
+	    if (ptr->ext_str_table == NULL) {
 		returnDB(TGETENT_NO);
 	    }
 	    if (Read(ptr->ext_str_table, (unsigned) ext_str_limit) != ext_str_limit) {
@@ -582,11 +582,11 @@ NCURSES_EXPORT(int)
 _nc_read_file_entry(const char *const filename, TERMTYPE2 *ptr)
 /* return 1 if read, 0 if not found or garbled */
 {
-    FILE *fp = 0;
+    FILE *fp = NULL;
     int code;
 
     if (_nc_access(filename, R_OK) < 0
-	|| (fp = safe_fopen(filename, BIN_R)) == 0) {
+	|| (fp = safe_fopen(filename, BIN_R)) == NULL) {
 	TR(TRACE_DATABASE, ("cannot open terminfo %s (errno=%d)", filename, errno));
 	code = TGETENT_NO;
     } else {
@@ -881,7 +881,7 @@ _nc_read_entry2(const char *const name, char *const filename, TERMTYPE2 *const t
 {
     int code = TGETENT_NO;
 
-    if (name == 0)
+    if (name == NULL)
 	return _nc_read_entry2("", filename, tp);
 
     _nc_SPRINTF(filename, _nc_SLIMIT(PATH_MAX)
@@ -891,7 +891,7 @@ _nc_read_entry2(const char *const name, char *const filename, TERMTYPE2 *const t
 	|| strcmp(name, ".") == 0
 	|| strcmp(name, "..") == 0
 	|| _nc_pathlast(name) != 0
-	|| strchr(name, NCURSES_PATHSEP) != 0) {
+	|| strchr(name, NCURSES_PATHSEP) != NULL) {
 	TR(TRACE_DATABASE, ("illegal or missing entry name '%s'", name));
     } else {
 #if NCURSES_USE_DATABASE
@@ -901,7 +901,7 @@ _nc_read_entry2(const char *const name, char *const filename, TERMTYPE2 *const t
 
 	_nc_first_db(&state, &offset);
 	code = TGETENT_ERR;
-	while ((path = _nc_next_db(&state, &offset)) != 0) {
+	while ((path = _nc_next_db(&state, &offset)) != NULL) {
 	    code = _nc_read_tic_entry(filename, PATH_MAX, path, name, tp);
 	    if (code == TGETENT_YES) {
 		_nc_last_db();
